@@ -25,7 +25,7 @@ build_time_vars = {'ABIFLAGS': '',
  'BYTESTR_DEPS': '\\',
  'CC': 'x86_64-pc-linux-gnu-gcc',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG',
+ 'CFLAGS': '-fno-strict-overflow -Wsign-compare',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
@@ -67,7 +67,7 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--with-system-libmpdec' '--with-platlibdir=lib' "
                 "'--with-pkg-config=yes' "
                 "'--with-wheel-pkg-dir=/usr/lib/python/ensurepip' "
-                "'--without-assertions' '--disable-optimizations' "
+                "'--with-assertions' '--disable-optimizations' "
                 "'--with-readline=readline' '--without-valgrind' '--with-lto' "
                 "'build_alias=x86_64-pc-linux-gnu' "
                 "'host_alias=x86_64-pc-linux-gnu' "
@@ -653,7 +653,7 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBDEST': '/usr/lib/python3.12',
  'LIBDIR': '/usr/lib64',
  'LIBEXPAT_A': 'Modules/expat/libexpat.a',
- 'LIBEXPAT_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 -pipe '
+ 'LIBEXPAT_CFLAGS': '-fno-strict-overflow -Wsign-compare -O2 -pipe '
                     '-march=x86-64-v3 -Werror=odr -Werror=lto-type-mismatch '
                     '-Werror=strict-aliasing -flto -flto -fuse-linker-plugin '
                     '-ffat-lto-objects -g -std=c11 -Wextra '
@@ -664,7 +664,7 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBEXPAT_HEADERS': '\\',
  'LIBEXPAT_OBJS': '\\',
  'LIBHACL_CFLAGS': '-I./Modules/_hacl/include -D_BSD_SOURCE -D_DEFAULT_SOURCE '
-                   '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 -pipe '
+                   '-fno-strict-overflow -Wsign-compare -O2 -pipe '
                    '-march=x86-64-v3 -Werror=odr -Werror=lto-type-mismatch '
                    '-Werror=strict-aliasing -flto -flto -fuse-linker-plugin '
                    '-ffat-lto-objects -g -std=c11 -Wextra '
@@ -679,7 +679,7 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBM': '-lm',
  'LIBMPDEC_A': 'Modules/_decimal/libmpdec/libmpdec.a',
  'LIBMPDEC_CFLAGS': '-DCONFIG_64=1 -DANSI=1 -DHAVE_UINT128_T=1 '
-                    '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 -pipe '
+                    '-fno-strict-overflow -Wsign-compare -O2 -pipe '
                     '-march=x86-64-v3 -Werror=odr -Werror=lto-type-mismatch '
                     '-Werror=strict-aliasing -flto -flto -fuse-linker-plugin '
                     '-ffat-lto-objects -g -std=c11 -Wextra '
@@ -1012,7 +1012,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MVWDELCH_IS_EXPRESSION': 1,
  'NO_AS_NEEDED': '-Wl,--no-as-needed',
  'OBJECT_OBJS': '\\',
- 'OPT': '-DNDEBUG',
+ 'OPT': '',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
  'PACKAGE_STRING': 0,
@@ -1047,8 +1047,8 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha2,sha3,blake2"',
- 'PY_BUILTIN_MODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
-                             '-pipe -march=x86-64-v3 -Werror=odr '
+ 'PY_BUILTIN_MODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare -O2 -pipe '
+                             '-march=x86-64-v3 -Werror=odr '
                              '-Werror=lto-type-mismatch '
                              '-Werror=strict-aliasing -flto -flto '
                              '-fuse-linker-plugin -ffat-lto-objects -g '
@@ -1059,7 +1059,7 @@ build_time_vars = {'ABIFLAGS': '',
                              '-fvisibility=hidden  -I./Include/internal -I. '
                              '-I./Include -I/usr/include/ncursesw -fPIC '
                              '-DPy_BUILD_CORE_BUILTIN',
- 'PY_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG',
+ 'PY_CFLAGS': '-fno-strict-overflow -Wsign-compare',
  'PY_CFLAGS_NODIST': '-O2 -pipe -march=x86-64-v3 -Werror=odr '
                      '-Werror=lto-type-mismatch -Werror=strict-aliasing -flto '
                      '-flto -fuse-linker-plugin -ffat-lto-objects -g -std=c11 '
@@ -1068,7 +1068,7 @@ build_time_vars = {'ABIFLAGS': '',
                      '-Werror=implicit-function-declaration '
                      '-fvisibility=hidden  -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
- 'PY_CORE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 -pipe '
+ 'PY_CORE_CFLAGS': '-fno-strict-overflow -Wsign-compare -O2 -pipe '
                    '-march=x86-64-v3 -Werror=odr -Werror=lto-type-mismatch '
                    '-Werror=strict-aliasing -flto -flto -fuse-linker-plugin '
                    '-ffat-lto-objects -g -std=c11 -Wextra '
@@ -1093,8 +1093,8 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_SQLITE_HAVE_SERIALIZE': 1,
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
- 'PY_STDMODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
-                        '-pipe -march=x86-64-v3 -Werror=odr '
+ 'PY_STDMODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare -O2 -pipe '
+                        '-march=x86-64-v3 -Werror=odr '
                         '-Werror=lto-type-mismatch -Werror=strict-aliasing '
                         '-flto -flto -fuse-linker-plugin -ffat-lto-objects -g '
                         '-std=c11 -Wextra -Wno-unused-parameter '
